# Updating a Lifecycle Phase and Approving the Quality Seal
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/updating-lifecycle-phase-and-approving-quality-seal#overview)
  * [Configuration](https://help.sap.com/docs/leanix/ea/updating-lifecycle-phase-and-approving-quality-seal#configuration)
  * [Script](https://help.sap.com/docs/leanix/ea/updating-lifecycle-phase-and-approving-quality-seal#script)


Configure an automation with a script to check lifecycle phases on fact sheets and require reapproval from fact sheet owners.
